@@ -17,31 +17,44 @@
 #'
 #' @export
 db_compute_boxplot <- function(data, x, var, coef = 1.5) {
-  x <- enexpr(x)
+  x <- enquo(x)
+  var <- enquo(var)
 
-  var <- enexpr(var)
-
-  data %>%
-    group_by(!! x) %>%
-    summarise(
-      lower = percentile_approx(!! var, 0.25),
-      middle = percentile_approx(!! var, 0.5),
-      upper = percentile_approx(!! var, 0.75),
-      max_raw = max(!! var, na.rm = TRUE),
-      min_raw = min(!! var, na.rm = TRUE)
-    ) %>%
-    mutate(iqr = (upper - lower) * coef) %>%
-    mutate(
-      min_iqr = lower - iqr,
-      max_iqr = upper + iqr
-    ) %>%
-    mutate(
-      ymax = ifelse(max_raw > max_iqr, max_iqr, max_raw),
-      ymin = ifelse(min_raw < min_iqr, min_iqr, min_raw)
-    ) %>%
-    collect() %>%
-    ungroup()
+  res <- group_by(data, !!x)
+  
+  if("tbl_spark" %in% class(res)) {
+    res <- summarise(
+      res,
+      lower  = percentile_approx(!!var, 0.25),
+      middle = percentile_approx(!!var, 0.5),
+      upper  = percentile_approx(!!var, 0.75),
+      max_raw = max(!!var, na.rm = TRUE),
+      min_raw = min(!!var, na.rm = TRUE)
+    ) 
+  } else {
+    res <- summarise(
+      res,
+      lower  = quantile(!!var, 0.25),
+      middle = quantile(!!var, 0.5),
+      upper  = quantile(!!var, 0.75),
+      max_raw = max(!!var, na.rm = TRUE),
+      min_raw = min(!!var, na.rm = TRUE)
+    ) 
+  }
 
+  res <- mutate(res, iqr = (upper - lower) * coef)
+  res <- mutate(
+    res,
+    min_iqr = lower - iqr,
+    max_iqr = upper + iqr
+  )
+  res <- mutate(
+    res,
+    ymax = ifelse(max_raw > max_iqr, max_iqr, max_raw),
+    ymin = ifelse(min_raw < min_iqr, min_iqr, min_raw)
+  )
+  res <- collect(res)
+  ungroup(res)
 }
 
 #' Boxplot
@@ -67,14 +80,13 @@ db_compute_boxplot <- function(data, x, var, coef = 1.5) {
 #'
 #' @export
 dbplot_boxplot <- function(data, x, var, coef = 1.5) {
-  x <- enexpr(x)
-
-  var <- enexpr(var)
+  x <- enquo(x)
+  var <- enquo(var)
 
   df <- db_compute_boxplot(
     data = data,
-    x = !! x,
-    var = !! var,
+    x = !!x,
+    var = !!var,
     coef = coef
   )
 
@@ -92,11 +104,12 @@ dbplot_boxplot <- function(data, x, var, coef = 1.5) {
         middle = middle,
         upper = upper,
         ymax = ymax
-      ), stat = "identity"
-    ) + labs(x = x)
+      ),
+      stat = "identity"
+    ) +
+    labs(x = x)
 }
 
-
 globalVariables(c(
   "upper", "ymax", "weight", "x_", "y", "aes", "ymin", "lower",
   "middle", "upper", "iqr", "max_raw", "max_iqr", "min_raw",
